API reference
=============

Search classes
--------------

.. automodule:: pydov.search.abstract
    :members:

Boring
******

.. automodule:: pydov.search.boring
    :members:

Sondering
*********

.. automodule:: pydov.search.sondering
    :members:

Grondwaterfilter
****************

.. automodule:: pydov.search.grondwaterfilter
    :members:

Grondwatermonster
*****************

.. automodule:: pydov.search.grondwatermonster
    :members:

Grondwatervergunning
********************

.. automodule:: pydov.search.grondwatervergunning
    :members:


Interpretaties
**************

.. automodule:: pydov.search.interpretaties
    :members:

Grondmonster
************

.. automodule:: pydov.search.grondmonster
    :members:

Bodemsite
*********

.. automodule:: pydov.search.bodemsite
    :members:

Bodemlocatie
************

.. automodule:: pydov.search.bodemlocatie
    :members:

Bodemdiepteinterval
*******************

.. automodule:: pydov.search.bodemdiepteinterval
    :members:

Bodemmonster
************

.. automodule:: pydov.search.bodemmonster
    :members:

Bodemobservatie
***************

.. automodule:: pydov.search.bodemobservatie
    :members:

Bodemclassificatie
******************

.. automodule:: pydov.search.bodemclassificatie
    :members:

Generic
*******

.. automodule:: pydov.search.generic
    :members:

Object types
------------

.. automodule:: pydov.types.abstract
    :members:

Boring
******

.. automodule:: pydov.types.boring
    :members:
    :show-inheritance:

Sondering
*********

.. automodule:: pydov.types.sondering
    :members:
    :show-inheritance:

Grondwaterfilter
****************

.. automodule:: pydov.types.grondwaterfilter
    :members:
    :show-inheritance:

Grondwatermonster
*****************

.. automodule:: pydov.types.grondwatermonster
    :members:
    :show-inheritance:

Grondwatervergunning
********************

.. automodule:: pydov.types.grondwatervergunning
    :members:
    :show-inheritance:

Interpretaties
**************

.. automodule:: pydov.types.interpretaties
    :members:
    :show-inheritance:

Grondmonster
************

.. automodule:: pydov.types.grondmonster
    :members:
    :show-inheritance:

Bodemsite
*********

.. automodule:: pydov.types.bodemsite
    :members:
    :show-inheritance:

Bodemlocatie
************

.. automodule:: pydov.types.bodemlocatie
    :members:
    :show-inheritance:

Bodemdiepteinterval
*******************

.. automodule:: pydov.types.bodemdiepteinterval
    :members:
    :show-inheritance:

Bodemmonster
************

.. automodule:: pydov.types.bodemmonster
    :members:
    :show-inheritance:

Bodemobservatie
***************

.. automodule:: pydov.types.bodemobservatie
    :members:
    :show-inheritance:

Bodemclassificatie
******************

.. automodule:: pydov.types.bodemclassificatie
    :members:
    :show-inheritance:

Generic
*******

.. automodule:: pydov.types.generic
    :members:
    :show-inheritance:

Fields
------

.. automodule:: pydov.types.fields
    :members:
    :show-inheritance:

.. automodule:: pydov.types.ligging
    :members:

Search utilities
----------------

Query
*****

.. automodule:: pydov.util.query
    :members:

Location
********

.. automodule:: pydov.util.location
    :members:
    :show-inheritance:

OWS utilities
*************

.. automodule:: pydov.util.owsutil
    :members:
    :show-inheritance:

DOV utilities
*************

.. automodule:: pydov.util.dovutil
    :members:
    :show-inheritance:

Caching
-------

.. automodule:: pydov.util.caching
    :members:
    :show-inheritance:

Hooks
-----

.. automodule:: pydov.util.hooks
    :members:
    :show-inheritance:

Network utilities
-----------------

.. automodule:: pydov.util.net
    :members:
    :show-inheritance:

Errors and warnings
-------------------

.. automodule:: pydov.util.errors
    :members:
    :show-inheritance:
